function runprop = cac_distributedDecodeFcn( runprop )
%CACNONSHAREDSIMPLEDECODEFCN Prepares a worker to run a MATLAB task.
% This function is referenced by cacNonSharedSimpleSubmitFcn.
% THIS FUNCTION MUST BE ON THE PATH OF THE MATLAB WORKERS;
% typically, this is accomplished by putting this function into
% $MATLABROOT/toolbox/local on the workers, or changing
% to the directory where this function is, before starting those
% MATLAB workers.

% Copyright 2006 The MathWorks, Inc.

% Read environment variables into local variables. The names of
% the environment variables were determined by the submit function


storageConstructor = getenv( 'MDCE_STORAGE_CONSTRUCTOR' );
storageLocation = getenv( 'MDCE_STORAGE_LOCATION' );
jobLocation = getenv( 'MDCE_JOB_LOCATION' );
taskLocation = getenv( 'MDCE_TASK_LOCATION' );

isZip = getenv('CACSCHEDULER_ZIP_JOB');

if ~isempty(isZip)
	%retrieve the fullpath to the zip file from the environment
	zipLocation = getenv('CACSCHEDULER_ZIP_LOCATION');
	pidFile = fullfile(storageLocation, jobLocation, '\LJZip.pid');
	%Figure out if we are task1, who is responsible for unzipping, in which case we have JobXX\Task1 as the taskLocation
	if strcmp(taskLocation,[jobLocation '\Task1'])
		%Create a .pid file in jobLocation to stop 
		%other tasks from running till it's gone
		dctSchedulerMessage(2, ['starting unzip ' char(java.util.Date)]);
		fid = fopen(pidFile,'w');
		fclose(fid);
		%The archive contains the JobXXX name, so we just unpack 
		%to the user's base directory.
		%storageLocation may not point to the base directory!
		inds = strfind(storageLocation,'\');
		if (length(inds)> 4)
			st = storageLocation(1:inds(5));
			files = unzip(zipLocation, st);
		else
			files = unzip(zipLocation,storageLocation)
		end
		%Ensure we have writeable files
		dctSchedulerMessage(2, ['setting writable ' char(java.util.Date)]);
		for i = 1:length(files)
			fileattrib(files{i},'+w');
		end
		%Cleanup the zip
		delete(zipLocation);
		%cleanup pid
		delete(pidFile);
		dctSchedulerMessage(2,['unzip complete ' char(java.util.Date)]);
	else
		%We're some other task, so we just wait for our Task 
		%files to be unzipped.  We give up after 1200 seconds.
		maxwait = 1200;
		totalwait = 0;
		taskOut = [taskLocation,'.in.mat'];
		taskFile  = fullfile(storageLocation,taskOut);
		while totalwait < maxwait
			pause(0.1);
			totalwait = totalwait + 0.1;
			%We wait for taskFile to exist and for
			%task1 to have deleted the pidfile
			if exist(taskFile) && ~exist(pidFile)
				fprintf('Task held %4.1fs to start',totalwait);
				totalwait = maxwait;
			end
		end
	end
end

% Set runprop properties from the local variables:
set( runprop, ...
    'StorageConstructor', storageConstructor, ...
    'StorageLocation', storageLocation, ...
    'JobLocation', jobLocation, ....
    'TaskLocation', taskLocation );