function runprop = cac_parallelDecodeFcn( runprop )
%PBSNONSHAREDPARALLELDECODEFCN Prepares a worker to run a MATLAB task.
% This function is referenced by pbsNonSharedParallelSubmitFcn.
% THIS FUNCTION MUST BE ON THE PATH OF THE MATLAB WORKERS;
% typically, this is accomplished by putting this function into
% $MATLABROOT/toolbox/local on the workers, or changing
% to the directory where this function is, before starting those
% MATLAB workers.

% Copyright 2006 The MathWorks, Inc.

% Read environment variables into local variables. The names of
% the environment variables were determined by the submit function
storageConstructor = getenv('MDCE_STORAGE_CONSTRUCTOR');
storageLocation = getenv('MDCE_STORAGE_LOCATION');
jobLocation = getenv('MDCE_JOB_LOCATION');
% For a parallel job, the task location is derived from labindex
taskLocation = [jobLocation filesep 'Task' num2str( labindex ) ];

isZip = getenv('CACSCHEDULER_ZIP_JOB');
if ~isempty(isZip)
	%retrieve the fullpath to the zip file from the environment
	zipLocation = getenv('CACSCHEDULER_ZIP_LOCATION');
	pidFile = fullfile(storageLocation, jobLocation, '\LJZip.pid');
	%We have access to labindex, which simplifies task identification
	%Task 1 is still responsible for unzipping
	if labindex == 1
		%Create a .pid file in jobLocation to stop 
		%other tasks from running till it's gone
		dctSchedulerMessage(2, ['starting unzip ' char(java.util.Date)]);
		fid = fopen(pidFile,'w');
		fclose(fid);
		%The archive contains the JobXXX name, so we just unpack 
		%to storage location.
		%storageLocation may contain a directory after the home.
		inds = strfind(storageLocation,'\');
		if (length(inds)> 4)
			st = storageLocation(1:inds(5));
			files = unzip(zipLocation, st);
		else
			files = unzip(zipLocation,storageLocation);
		end
			%Ensure we have writeable files
		dctSchedulerMessage(2, ['setting writable ' char(java.util.Date)]);
		for i = 1:length(files)
			fileattrib(files{i},'+w');
		end
		%Cleanup the zip
		delete(zipLocation);
		%cleanup pid
		delete(pidFile);
		dctSchedulerMessage(2,['unzip complete ' char(java.util.Date)]);
		%catch exception
		%	error('CAC Error!', exception.message);
		%end
	end
	% all tasks wait for unzip to complete
	
	labBarrier;
end


% Set runprop properties from the local variables:
set(runprop, ...
        'StorageConstructor', storageConstructor, ...
        'StorageLocation', storageLocation, ...
        'JobLocation', jobLocation, ...
        'TaskLocation', taskLocation);