function sendDirToCAC(lDir,rDir)
% SENDDIRTOCAC recursively copy directory from local system to cac
%
% sendDirToCAC(lDir,rDir)
%
% lDir   local directory
% rDir   remote directory basename
%
% If rDir already exists the contents of lDir are added, overwriting
% existing files as neccessary.
%
% Examples
%
% Send the contents of local directory named 'test' that must exist in the
% current working directory to a directory called 'test' on Red Cloud. The remote
% directory 'test' will be created if necessary:
%
%   sendDirToCAC('test','test');
%
% Send the contents of local directory 'lTest', which must exist in the
% current working directory, to the directory 'rTest' on Red Cloud. The remote
% directory 'rTest' will be created if necessary:
%
%   sendDirToCAC('lTest','rTest');
%
% Add the contents of local directory 'test2' to remote directory 'rTest'
% (created in previous example). A warning that 'rTest' already exists will
% occur, as will warning about other subdirectories in common between
% 'test2' and 'rtest'.  Remote files will be overwritten if they conflict.
%
%   sendDirToCAC('test2','test');
%
% Remote and absolute paths are accepted for the local directory
%
%   sendDirToCAC('c:\projects\matlab\test','test');
%   sendDirToCAC('subdir/subdir','test');
%
% Absolute or relative remote paths can be used but must exist.  See
% gridFTP to create directory structures manually. The following moves the
% contents of local directory '/home/matlab/data' to remote directory
% 'test/subdir' ONLY if test already exists:
%
%   sendDirToCAC('/home/matlab/data','test/subdir')
%
% See also sendFileToCAC, gridFTP, cacscheduler
%
% Copyright 2009-2010 Cornell Center for Advanced Computing
% Modified by LSF

%% Check arguments
error(nargchk(2,2,nargin,'struct'));
error(nargoutchk(0,0,nargout,'struct'));

myftp = gridFTP();
myftp.rput(lDir,rDir,1);
myftp.close();


