function sendFileToCAC(localFile)
%SENDFILETOCAC(localfile) - send a single local file to Red Cloud storage system
% preserving the name of the file locally, but ignoring any path.  You
% should add a path dependency in your job to refer to this directory:
% set(job,'PathDependencies',{'\\matlabstorage01\matlab\username'});
%
% EXAMPLES:
% The following examples all move a single local file (that must exist) to
% your data directory on Red Cloud.
%
% Send a single file in the current directory to Red Cloud
%   sendFileToCAC('colSum.m');
% Send single file in a subdirectory to Red Cloud - note the file is not put in
% subdir/file.mat on Red Cloud!
%   sendFileToCAC('examples/cacMex.m');
% Absolute paths also work:
%   sendFileToCAC('/home/matlab/userid/functions/work24.mat');
% 
%  See also sendDirToCAC, gridFTP, cacscheduler
%
% Copyright 2009-2010 Cornell Center for Advanced Computing

%Ensure the file exists first
if exist(localFile,'file') == 0
    fprintf('%s doesn''t appear to exist on your filesystem.\nPlease double check the name and path.\n',localFile);
    return
end

myftp = gridFTP();
lFile = java.io.File(localFile);
name = char(lFile.getName());
myftp.put(localFile,name);
myftp.close();

